\name{migraine}
\docType{data}
\alias{migraine}
\title{Longitudinal Study on Migraine Severity}
\description{Data on migraine severity in 119 Canadian (Toronto) patients}
\usage{data(migraine)}
\format{
  This data frame contains 16,366 rows and the following columns:

  \strong{Responses}
  \describe{
    \item{HA}{headache severity: \code{0} absence, \code{1} mild,
      \code{2} moderate, \code{3} painful, \code{4} severe,
      \code{5} intense}
  }
  \strong{Personal covariates}
  \describe{
    \item{AGE}{age of patient}
    \item{ED}{educational level: \code{1} less than highschool, \code{2}
      highschool, \code{3} trade or technical training, \code{4} community
      college, \code{5} BA, \code{6} MA, \code{7} PhD}
    \item{EMPL}{employment status: \code{1} full-time, \code{2}
      part-time, \code{3} on disability, \code{4} unemployed, \code{5}
      other}
    \item{MARITAL}{marital status: \code{1} single, \code{2} married,
      cohabitating, \code{3} separated, \code{4} divorced, \code{5}
      widowed}
    \item{OCC}{occupation: \code{1} professional/executive manager,
      \code{2} skilled worker, \code{3} clerical worker, \code{4}
      semi-skilled or un-skilled, \code{5} homemaker, \code{6} unemployed,
      \code{7} student, \code{8} retired}
    \item{PERIOD}{measurement period index: the numeric part correspond to \code{SUBJECT} while the following alphabetic part to the measurement period}
    \item{SEX}{gender: \code{M}ale, \code{F}emale}
    \item{SMOKE}{currently smokes cigarettes:
      \code{Y}es, \code{N}o}
    \item{SUBJECT}{patient index}
    \item{WEATHER}{patient indication weather is a trigger for their
      headache: \code{Y}es, \code{N}o}
  }
  \strong{Clinical covariates}
  \describe{
    \item{COPHYS}{comorbid physical illness(es): \code{Y}es, \code{N}o}
    \item{COPSYC}{comorbid psychological condition(s): \code{Y}es, \code{N}o}
    \item{HATYPE}{headache type: \code{1} migraine without aura, 
      \code{2} migraine with aura, \code{3} mixed migraine/tension
      headache}
    \item{MEDANALG}{current analgesic medication intake for headache:
      \code{Y}es, \code{N}o}
    \item{MEDNONHA}{current medication taken for reason other than headache:
      \code{Y}es, \code{N}o}
    \item{MEDOTHER}{current other medication intake for headache :
      \code{Y}es, \code{N}o}
    \item{MEDPROPH}{current prophylactic medication intake for headache:
      \code{Y}es, \code{N}o}
    \item{NEO}{neuroticism domain T score}
    \item{YRSSUFF}{years suffering from migraine}
  }
 \strong{Calendar covariates}
  \describe{
    \item{DAY}{day on which headache was recorded}
    \item{DATE}{date on which headache was recorded}
    \item{INTRADAY}{moment of the day on which headache was recorded: 
      \code{AM}, \code{NOON}, \code{PM}, \code{BED}}
    \item{MONTH}{month on which headache was recorded}
    \item{SEASEQ}{season - by equinoxes and solstices: \code{SPR} Spring,
      \code{SUM} Summer, \code{FALL} Fall, \code{WINT} Winter}
    \item{SEASMET}{season - metheorologist's version by month: \code{SPR} Spring,
      \code{SUM} Summer, \code{FALL} Fall, \code{WINT} Winter}
    \item{WDAY}{day of the week  on which headache was recorded:
      \code{MON} Monday, \code{TUES} Tuesday, \code{WED} Wednesday,
      \code{THUR} Thursday, \code{FRI} Friday, \code{SAT} Saturday,
      \code{SUN} Sunday}
    \item{YEAR}{year on which headache was recorded}
  }
  \strong{Weather covariates}
  \describe{
    \item{AHDXD}{humidity index based on the change since the day before}
    \item{AQISTN}{Air Quality Index Station (nine stations)}
    \item{AQMAX}{maximum AQI; day of measurement}
     \item{AQMAX1P}{maximum AQI; previous day}
    \item{AWCHILLD}{windchilld index based on the change since the day before}
    \item{CA}{cloud total amount (tenths); day of measurement}
\item{CA1P}{cloud total amount (tenths); previous day}
    \item{DHDX}{the amount of humidity index above yesterday level}
    \item{MAXHD}{humidity index  based on max. temp and humidity
      per 24 hours; day of measurement}
\item{MAXHD1P}{humidity index  based on max. temp and humidity
      per 24 hours; previous day}
    \item{MINWC}{windchilld based on min. temp and windspeed per hour; day of measurement}
\item{MINWC1P}{windchilld based on min. temp and windspeed per hour; previous day}
    \item{PMN}{pressure - mean sea level (.01 kilopascals); day of measurement}
\item{PMN1P}{pressure - mean sea level (.01 kilopascals); previous day}
    \item{PMND}{pressure - mean sea level (.01 kilopascals); change from previous day}
    \item{PREC}{precipitation total amount, snow and rain (.1mm); day of measurement}
    \item{PREC1P}{precipitation total amount, snow and rain (.1mm); previous day}
    \item{RHMN}{mean relative humidity (\%); day of measurement}
\item{RHMN1P}{mean relative humidity (\%); previous day}
    \item{S}{sunshine total amount (hours); day of measurement}
\item{S1P}{sunshine total amount (hours); previous day}
    \item{THUN}{thunderstorm total daily severity; day of
      measurement: \code{0} no thunderstorm, \code{1} thunderstorm}
\item{THUN1P}{thunderstorm total daily severity; previous day: \code{0} no thunderstorm, \code{1} thunderstorm}
      \item{TMN}{mean temperature (degree Celsius); day of measurement}
      \item{TMN1P}{mean temperature (degree Celsius); previous day}
      \item{TMND}{mean tempertature (degree Celsius); change from previous day}
      \item{WSMAX}{maximum wind speed (km/hr); day of measurement}
 \item{WSMAX1P}{maximum wind speed (km/hr;, previous day)}
      \item{WSTN}{weather station (three weather)}   	
}     
}
\source{
  Dr. Tommy Kostecki-Dillon.  
}
\seealso{\code{\link{maop}}}
\references{
 Varin, C. and Czado, C. (2009). A mixed autoregressive probit model for
 ordinal longitudinal data. \emph{Biostatistics}, to appear. 
}
\keyword{datasets}