## Copyright (C) 2020 Ioannis Kosmidis

## Distributed as part of the supplementary material for the manuscript
## "Empirical bias-reducing adjustments to estimating functions"
##
## Authors: Ioannis Kosmidis
## Date: 06 January 2020
## Licence: GPL 2 or greater
## NOT A POLISHED PIECE OF PUBLIC-USE SOFTWARE!  Provided "as is".
## NO WARRANTY OF FITNESS FOR ANY PURPOSE!


library("enrichwith")
load_all("~/Repositories/brglm2")
library("parallel")
source("binomial_regression_functions.R")

## save path
image_path <- "images/"

## number of cores
n_cores <- 7

## number of base simulations
n_simu <- 10000


## number of rows in X matrix
n_obs_vec <- c(75, 150, 300, 600, 1200)


## True parameter values
betas <- c(-1, 0, 0, 1, 1)/2
## betas <- c(1, 1, 0, 0, -1)/2

## True model
paste(which(betas != 0), collapse = "-")

## link
link <- make.link("probit")


for (n_obs in n_obs_vec) {

    ## Model matrix
    set.seed(123)
    x1 <- rnorm(n_obs)
    x2 <- rbinom(n_obs, 1, 0.25)
    x3 <- rbinom(n_obs, 1, 0.75)
    x4 <- rexp(n_obs)
    X <- cbind(1, x1, x2, x3, x4)
    
    ## Linear predictors
    etas <- drop(X %*% betas)
    ## Dummy fit to be enriched with scores, information and simulate function
    y <- rbinom(nrow(X), 1, link$linkinv(etas))
    temp_ml <- glm(y ~ -1 + X, family = binomial(link))
    simu <- get_simulate_function(temp_ml)
    simu_data <- simu(betas, nsim = n_simu, seed = 123)

    res <- mclapply(seq.int(n_simu), function(j) {
        out <- try(fit_all_models(X, simu_data[, j], link))
        model_names <- rownames(out$models)
        crit_ml <- colnames(out$ic_ml)
        crit_tr <- colnames(out$ic_pml)
        crit_br <- colnames(out$ic_br)
        selected_model_ml <- structure(model_names[apply(out$ic_ml, 2, which.min)],
                                       names = crit_ml)
        selected_model_pml <- structure(model_names[apply(out$ic_pml, 2, which.min)],
                                        names = crit_tr)
        selected_model_br <- structure(model_names[apply(out$ic_br, 2, which.min)],
                                       names = crit_br)
        if (j %% 100 == 0) cat("sample:", j, "nobs", n_obs, "Done!\n")
        list(model_ml = selected_model_ml,
             model_pml = selected_model_pml,
             model_br = selected_model_br,
             coef_ml = out$coef_ml,
             coef_br = out$coef_br,
             coef_pml = out$coef_pml,
             separated = out$separated,
             converged_ml = out$converged_ml,
             converged_br = out$converged_br,
             converged_tr = out$converged_tr,
             infinite_ml = out$infinite_ml)
    }, mc.cores = n_cores)

    save(list = c("res", "n_obs", "n_simu", "X", "betas", "simu_data"),
         file = file.path(image_path, paste0("model_selection_", n_obs, ".rda")))

}
